@@ -10,7 +10,8 @@ with versions which support operators.
 The defined operators are:
   &  - amap
   >> - bind
-  *  - map
+  << - map
+  *  - then
 
   Example:
     from pymonad.operators import Maybe, Just, Nothing
@@ -27,8 +28,12 @@ The defined operators are:
             return Just(x / y)
 
     # Equivalent to Maybe.apply(add).to_arguments(Just(1), Just(2))
-    print(add * Just(1) & Just(2)) # Just 3
+    print(add << Just(1) & Just(2)) # Just 3
 
     # Equivalent to Maybe.insert(5).bind(div(2)).bind(div(0))
     print(Just(5) >> div(2) >> div(0)) # Nothing
-"""
\ No newline at end of file
+
+    # Alternatively, each could be written with *
+    print(add * Just(1) & Just(2)) # Just 3
+    print(Just(5) * div(2) * div(0)) # Nothing
+"""
